
// (c) COPYRIGHT URI/MIT 1997-98
// Please read the full copyright statement in the file COPYRIGHT.  
//
// Authors: reza (Reza Nekovei)

// This is the main CGI program which extracts DDS class descriptors from a
// FreeForm format file. In addition, the descriptors from an external file
// (if exist, with the same name as the data file and extension of .dds) are
// extracted and added to the in-memory DDS table before it is sent over the
// network to the client side.
//
// ReZa 6/20/97

#include "config_ff.h"

static char rcsid[] not_used = {"$Id: ff_dds.cc,v 1.11 2000/10/12 18:11:45 jimg Exp $"};

#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <string.h>

#include <string>
#include <iostream>

#include "DDS.h"
#include "Error.h"
#include "cgi_util.h"
#include "DODSFilter.h"
#include "ce_functions.h"

// These must be defined here to resolve symbols declared as extern in
// FFByte.cc, ... 8/12/98 jhrg

long BufPtr = 0;		// Cache pointer
long BufSiz =0;			// Cache size
char *BufVal = NULL;		// Cache buffer

extern void read_descriptors(DDS &dds, const string &filename) throw (Error);

int 
main(int argc, char * argv[])
{
    DDS dds;
    dds.add_function("date", func_date);

    DODSFilter df(argc, argv);

    if (!df.OK()) {
	df.print_usage();
	return 1;
    }

    if (df.version()) {
	df.send_version_info();
	return 0;
    }

    // This software is between using return values for error reporting and
    // using exceptions. It should change to exceptions only. 5/3/99 jhrg
    try {
      read_descriptors(dds, df.get_dataset_name());

      df.read_ancillary_dds(dds);

      df.send_dds(dds, true);
    }
    catch (Error &e) {
      ErrMsgT(e.get_error_message());
      set_mime_text(cout, dods_error, df.get_cgi_version());
      e.print(cout);
      return 1;
    }

    return 0;
}

// $Log: ff_dds.cc,v $
// Revision 1.11  2000/10/12 18:11:45  jimg
// Added more exception stuff. Reworked the get/read_description() functions
// so they throw Error and InternalErr instead of returning codes.
//
// Revision 1.10  2000/10/11 19:37:56  jimg
// Moved the CVS log entries to the end of files.
// Changed the definition of the read method to match the dap library.
// Added exception handling.
// Added exceptions to the read methods.
//
// Revision 1.9  1999/05/27 17:02:23  jimg
// Merge with alpha-3-0-0
//
// Revision 1.8.2.1  1999/05/20 21:43:36  edavis
// Fix spelling of COPYRIGHT and remove some #if 0 stuff.
//
// Revision 1.8  1999/05/05 01:36:44  jimg
// Fixed catch block; must send MIME header before Error object gets
// serialized.
//
// Revision 1.7  1999/05/04 02:55:37  jimg
// Merge with no-gnu
//
// Revision 1.6.10.1  1999/05/01 04:40:29  brent
// converted old String.h to the new std C++ <string> code
//
// Revision 1.6  1998/09/17 17:42:49  jimg
// Added installation of date_func in DDS.
//
// Revision 1.5  1998/08/12 21:21:10  jimg
// Massive changes from Reza. Compatible with the new FFND library
//
// Revision 1.4  1998/04/21 17:14:08  jimg
// Fixes for warnings, etc
//
// Revision 1.3  1998/04/16 18:11:23  jimg
// Sequence support added by Reza
